@@ -6,6 +6,7 @@ from typing import Optional
 
 from yangke.base import get_settings, run_once
 import os
+# ------------------------------ 使用loguru时的代码 --------------------------------------
 from loguru import logger as logger1
 import loguru
 
@@ -14,6 +15,13 @@ Logger = loguru._logger.Logger
 # 该类中一律使用logger，不使用全局变量模块中的gv.logger，这样就无须引入全局变量模块.
 # 调用模块会将gv.logger设置为这里的logger，但因为该类可以直接访问自己的logger，就无须且不建议使用gv.logger
 logger: Logger = logger1
+# ------------------------------ 使用loguru时的代码 --------------------------------------
+
+# ------------------------------ 使用nb_log时的代码 --------------------------------------
+# from logging import Logger
+# from nb_log import get_logger
+# logger = get_logger(None)
+# ------------------------------ 使用nb_log时的代码 --------------------------------------
 # noinspection all
 level: int = None
 # 这里声明以下变量，这样在其他模块中引用config时无须引入logging模块即可使用以下变量
@@ -437,7 +445,8 @@ def add_file_logger(log_file: Optional[str] = "default", rotation="50 MB", reten
         log_file = "runtime_{time}.log"
 
     if log_file is not None:
-        log_file_id = logger.add(log_file, level=level, rotation=rotation, retention=retention, diagnose=diagnose)
+        log_file_id = logger.add(log_file, encoding="utf8", level=level, rotation=rotation, retention=retention,
+                                 diagnose=diagnose)
 
 
 def __import_first__():
@@ -450,7 +459,6 @@ def __import_first__():
     dateFormat = settings.get('dateFormat')
     logger = initLogger(level_color=levelColor, format_color=formatColor, log_format=logFormat,
                         date_format=dateFormat)
-    add_file_logger()
 
 
 prior = 0  # 用来控制临时修改日志级别的变量
