@@ -5,7 +5,7 @@
 # Copyright (C) October 18, 2017
 # http://www.wyattllc.com
 # 注意：引入本文件就需要可用的Ebsilon授权和EbsOpen授权
-
+import os.path
 from enum import Enum
 from typing import Optional
 
@@ -920,7 +920,7 @@ class EbsModel:
         """
         self.model = model
 
-    def set_value(self, component, abbr, value, unit: EbsUnits = None, save_flag=True):
+    def set_value(self, component, abbr, value: str | float, unit: EbsUnits = None, save_flag=True):
         """
         设置模型中某个组件中的参数
 
@@ -932,6 +932,10 @@ class EbsModel:
         :return:
         """
         comp = self.object_by_context(component)  # 不能使用get_object
+        try:
+            value = float(value)
+        except:
+            pass
         comp.set_value(abbr=abbr, value=value, unit=unit, save_flag=save_flag)
 
     def get_value(self, component, abbr, unit=None):
@@ -1088,6 +1092,8 @@ class EbsModel:
         :param filepath:
         :return:
         """
+        if not os.path.exists(os.path.dirname(filepath)):
+            os.makedirs(os.path.dirname(filepath))
         result: bool = self.model.SaveAs(filepath)
         return result
 
