@@ -8,7 +8,7 @@ from ..base import get_settings, getAbsPath, pic2ndarray, draw_element_on_pic, c
 from PIL import Image, ImageDraw, ImageFont
 import dlib
 from ..common.config import logger, loggingTitleCall
-import yangke.common.mysql as mysql
+import yangke.dataset.mysql as mysql
 import datetime
 import time
 from DBUtils.PooledDB import PooledDB
@@ -1783,7 +1783,6 @@ def recognize_face_cam():
     #   2. Only detect faces in every other frame of video.
 
     # Get a reference to webcam #0 (the default one)
-    import face_recognition
     video_capture = cv2.VideoCapture(0, cv2.CAP_DSHOW)
 
     known_face_encodings = []
