@@ -160,8 +160,8 @@ class YOLOLayer(nn.Module):
             for j in range(n):
                 if j != i:
                     p += w[:, j:j + 1] * \
-                         F.interpolate(out[self.layers[j]][:, :-n], size=[ny, nx], mode='bilinear',
-                                       align_corners=False)
+                         F.interpolate_nd(out[self.layers[j]][:, :-n], size=[ny, nx], mode='bilinear',
+                                          align_corners=False)
 
 
         else:
@@ -410,7 +410,7 @@ def scale_img(img, ratio=1.0, same_shape=True):  # img(16,3,256,416), r=ratio
     # scales img(bs,3,y,x) by ratio
     h, w = img.shape[2:]
     s = (int(h * ratio), int(w * ratio))  # new size
-    img = F.interpolate(img, size=s, mode='bilinear', align_corners=False)  # resize
+    img = F.interpolate_nd(img, size=s, mode='bilinear', align_corners=False)  # resize
     if not same_shape:  # pad/crop img
         gs = 64  # (pixels) grid size
         h, w = [math.ceil(x * ratio / gs) * gs for x in (h, w)]
