@@ -226,7 +226,7 @@ def select_device(device='', apex=False, batch_size=None):
             if i == 1:
                 s = ' ' * len(s)
             print("%sdevice%g _CudaDeviceProperties(name='%s', total_memory=%dMB)" %
-                  (s, i, x[i].name, x[i].total_memory / c))
+                  (s, i, x[i].NAME, x[i].total_memory / c))
     else:
         print('Using CPU')
 
