@@ -1279,7 +1279,7 @@ def train():
                 sf = img_size / max(imgs.shape[2:])  # scale factor
                 if sf != 1:
                     ns = [math.ceil(x * sf / gs) * gs for x in imgs.shape[2:]]  # new shape (stretched to 32-multiple)
-                    imgs = F.interpolate(imgs, size=ns, mode='bilinear', align_corners=False)
+                    imgs = F.interpolate_nd(imgs, size=ns, mode='bilinear', align_corners=False)
 
             # Run model
             pred = model(imgs)
