@@ -19,7 +19,7 @@ from yangke.common.config import logger
 from yangke.performance.basic_para import pressure_absolute, pressure_relative  # 不能删除，本文件有隐含式引用
 from yangke.common.qt import YkWindow, YkDataTableWidget, set_menu_bar
 from yangke.core import str_in_list
-from yangke.common.fileOperate import read_csv_ex, writeAsPickle, readFromPickle
+from yangke.common.fileOperate import read_csv_ex, write_as_pickle, read_from_pickle
 from yangke.base import merge_two_dataframes, save_as_xlsx
 import time
 
@@ -341,7 +341,6 @@ def deal_poor_or_bad_parameters(poor_series: pd.Series):
 
 
 class MainWindow(YkWindow, QObject):
-    yk_signal = pyqtSignal(str, str)
 
     def __init__(self):
         # noinspection PyTypeChecker
@@ -431,7 +430,7 @@ class MainWindow(YkWindow, QObject):
             data_no_time = data.iloc[:, 1:].copy()
             mean = data_no_time.mean(axis=0)
             condition_name = os.path.splitext(os.path.basename(file))[0].replace(suffix_p_10, "")
-            mean.name = condition_name
+            mean.NAME = condition_name
             series.append(mean)
         df = pd.concat(series, axis=1)
         # 将df中工况按工况记录单排序
@@ -499,7 +498,7 @@ class MainWindow(YkWindow, QObject):
             kwargs_.update(self.config)
             data_no_time = deal_liquid_level(data_no_time, **kwargs_)
             mean = data_no_time.mean(axis=0)
-            mean.name = condition
+            mean.NAME = condition
             series.append(mean)
         df = pd.concat(series, axis=1)
         outfile = self.unknown_file
@@ -533,13 +532,14 @@ class MainWindow(YkWindow, QObject):
         return df
 
     def init_ui(self):
-        self.data_folder = get_temp_para('directory', get_func=lambda: "c:\\")
+        self.data_folder = get_temp_para('directory', get_func_or_default_value=lambda: "c:\\")
         self.project_file = os.path.join(self.data_folder, "project.dat")
 
-        self.config.update(readFromPickle(self.project_file) or {})
+        self.config.update(read_from_pickle(self.project_file) or {})
 
         def choose_file(table: YkDataTableWidget):
-            folder = QFileDialog.getExistingDirectory(parent=self, caption="选择数据存储目录", directory=self.data_folder)
+            folder = QFileDialog.getExistingDirectory(parent=self, caption="选择数据存储目录",
+                                                      directory=self.data_folder)
             if folder != self.data_folder:
                 self.data_folder = folder
                 save_temp_para("directory", folder)
@@ -549,168 +549,13 @@ class MainWindow(YkWindow, QObject):
             self.progressBar.setVisible(True)
             self.statusBar().showMessage("处理试验数据...")
             self.progressBar.setValue(0)
-            self.config.update({"水位计算点数"     : self.table_widget.get_value("水位计算点数"),
-                                "使用表号确定压力类型" : self.table_widget.get_value("使用表号确定压力类型"),
+            self.config.update({"水位计算点数": self.table_widget.get_value("水位计算点数"),
+                                "使用表号确定压力类型": self.table_widget.get_value("使用表号确定压力类型"),
                                 "未知类型文件区分文件名": self.table_widget.get_value("未知类型文件区分文件名")})
 
-            def task_func():
-                """
-                启动新线程运行耗时较长的方法
-                不能在该线程中创建或修改父线程的GUI元素，如果需要修改GUI，必须使用yk_signal触发QEvent事件调用父线程的方法
-                :return:
-                """
-                folder = table.get_value("目录")
-                self.imp_file = os.path.join(folder, suffix_imp_20 + ".xlsx")
-                self.dcs_file = os.path.join(folder, suffix_dcs_20 + ".xlsx")
-                self.power_file = os.path.join(folder, suffix_p_20 + ".xlsx")
-                self.unknown_file = os.path.join(folder, "unk汇总_修正.xlsx")  # 未识别格式的文件的统计数据
-                self.test_time, self.test_time_file = get_test_time(folder)  # 查询工况记录单
-                logger.debug(f"工况记录单文件为：{self.test_time_file}")
-                number_con = len(self.test_time.keys())
-                logger.info(f"工况记录单中查寻到的工况共{number_con}个！")
-                logger.info(str(list(self.test_time.keys())))
-                dcs_tested = []
-                dcs_individual_file = []  # dcs预处理后的单个储存文件
-                imp_or_wsn_tested = []
-                imp_individual_file = []  # imp数据预处理后的单个储存文件列表
-                power_tested = []
-                power_individual_file = []  # 功率数据预处理后的单个储存文件列表
-                unknown_tested = []
-                unknown_individual_file = []
-                step = 0
-                for file in yield_all_file(folder, [".csv", ".xlsx", ".dat", ".docx", ".txt", ".xls"]):
-                    step = step + 1 if step < 100 else 0
-                    # self.progressBar.setValue(step)
-                    # noinspection all
-                    self.yk_signal.emit("eval", "self.progressBar.setValue(" + str(step) + ")")
-                    if os.path.splitext(os.path.basename(file))[0].endswith("修正") or "ignore" in os.path.abspath(
-                            file) or "忽略该文件" in os.path.abspath(file):
-                        logger.info(f"忽略文件{file}")
-                        continue
-                    logger.debug(f"处理文件 {file}...")
-                    if os.path.splitext(file)[1] == ".xls":
-                        # 将xls格式文件另存为csv文件，csv的兼容性最好，然后进行进一步的处理
-                        file = save_as_xlsx(file, engine="WPS", ext="xlsx")
-                    # 预处理文件，如果文件中包含“时间-数据”条目，则剪切到对应工况的时间段，返回文件类型及剪切后的文件
-                    cutting_result = pre_deal_and_cutting_period(file, self.test_time, self.bound, self.config)
-                    if cutting_result:
-                        if isinstance(cutting_result, tuple) and cutting_result[0] == "power_slice":
-                            power_tested.extend(cutting_result[2])
-                            power_individual_file.extend(cutting_result[1])
-                        elif isinstance(cutting_result, tuple) and cutting_result[0] == "imp_slice":
-                            imp_or_wsn_tested.extend(cutting_result[2])
-                            imp_individual_file.extend(cutting_result[1])
-                            self.config.update({"imp_or_wsn_tested": imp_or_wsn_tested})
-                        elif isinstance(cutting_result, tuple) and cutting_result[0] == "wsn_slice":
-                            for condition in cutting_result[2]:
-                                file1 = cutting_result[1][
-                                    cutting_result[2].index(condition)]  # 找到condition的索引，然后按该索引拿到对应的文件名
-                                if condition in imp_or_wsn_tested:
-                                    file2 = imp_individual_file[imp_or_wsn_tested.index(condition)]
-                                    data1 = pd.read_csv(file1)
-                                    data2: pd.DataFrame = pd.read_csv(file2)
-                                    data2, dropped_cols = merge_two_dataframes(data1, data2)
-                                    data2[data2 == 0.000] = np.nan
-                                    data2.to_csv(file2, index=False)
-                                    os.remove(file1)
-                                else:
-                                    file2 = os.path.join(os.path.dirname(file1), f"{condition}{suffix_imp_10}.csv")
-                                    if os.path.exists(file2):
-                                        os.remove(file2)
-                                    os.rename(file1, file2)
-                                    imp_or_wsn_tested.append(condition)
-                                    imp_individual_file.append(file2)
-                        elif isinstance(cutting_result, tuple) and cutting_result[0] == "dcs_slice":
-                            # cutting_result[1] 为DCS处理后文件
-                            for condition in cutting_result[2]:
-                                file1 = cutting_result[1][
-                                    cutting_result[2].index(condition)]  # 找到condition的索引，然后按该索引拿到对应的文件名
-                                if condition in dcs_tested:
-                                    # 如果已经存在当前工况的数据，则合并已有数据和当前数据
-                                    file2 = dcs_individual_file[dcs_tested.index(condition)]
-                                    data1 = pd.read_csv(file1)
-                                    data2 = pd.read_csv(file2)
-                                    # 合并两个dataframe，自动判断按行还是按列合并
-                                    # 合并的两种情况：
-                                    # 1. 两个data的列名相同，但时间段不同，则将data2续到data1的最后一行之后，作为新行
-                                    # 2. 两个data的时间段相同，但列名（即参数不同，一般来自DCS系统中导出的不同的趋势组数据）不同，
-                                    #    则将data1和data2的列拼接起来。可能还存在更复杂的情况，目前已测试完成。
-                                    data2, dropped_cols = merge_two_dataframes(data1, data2)
-                                    # data2[data2 == 0.000] = np.nan  # dcs中的数据就有可能全是0，不能替换为np.nan，否则0不显示
-                                    self.dropped_dcs_cols = list(set(self.dropped_dcs_cols).union(set(dropped_cols)))
-                                    data2.to_csv(file2, index=False)
-                                    os.remove(file1)
-                                else:
-                                    file2 = os.path.join(os.path.dirname(file1), f"{condition}{suffix_dcs_10}.csv")
-                                    # 否则，将当前工况的数据文件名更改为最终数据文件名，并在存在工况列表中添加当前工况
-                                    if os.path.exists(file2):
-                                        os.remove(file2)
-                                    os.rename(file1, file2)
-                                    dcs_tested.append(condition)
-                                    dcs_individual_file.append(file2)
-                        elif isinstance(cutting_result, tuple) and cutting_result[0] == "unk_slice":
-                            for condition in cutting_result[2]:
-                                file1 = cutting_result[1][
-                                    cutting_result[2].index(condition)]  # 找到condition的索引，然后按该索引拿到对应的文件名
-                                if condition in unknown_tested:
-                                    # 如果已经存在当前工况的数据，则合并已有数据和当前数据
-                                    file2 = unknown_individual_file[unknown_tested.index(condition)]
-                                    data1 = pd.read_csv(file1)
-                                    data2 = pd.read_csv(file2)
-                                    data2, dropped_cols = merge_two_dataframes(data1, data2)
-                                    # data2[data2 == 0.000] = np.nan  # 有些数如循泵功率一直为0，不能替换为np.nan
-                                    data2.to_csv(file2, index=False)
-                                    os.remove(file1)
-                                else:
-                                    file2 = os.path.join(os.path.dirname(file1), f"{condition}_剪切unk时间_修正.csv")
-                                    # 否则，将当前工况的数据文件名更改为最终数据文件名，并在存在工况列表中添加当前工况
-                                    if os.path.exists(file2):
-                                        os.remove(file2)
-                                    os.rename(file1, file2)
-                                    unknown_tested.append(condition)
-                                    unknown_individual_file.append(file2)
-                        elif isinstance(cutting_result, tuple) and cutting_result[0] == "kp_hollysys":
-                            logger.debug("发现和利时点表文件")  # 和利时的点表文件
-                            if self.point_description is None:
-                                self.point_description = cutting_result[1]
-                            else:
-                                self.point_description.update(cutting_result[1])
-                # noinspection all
-                self.yk_signal.emit("eval", "self.statusBar().showMessage('汇总试验数据...')")
-                # noinspection all
-                self.yk_signal.emit("eval", "self.progressBar.setValue(0)")
-
-                if len(imp_or_wsn_tested) != len(self.test_time.keys()):
-                    logger.warning(f"imp采集数据工况找到{len(imp_or_wsn_tested)}个，少于工况记录单记录"
-                                   f"工况数量{len(self.test_time.keys())}")
-                if len(power_tested) != len(self.test_time.keys()):
-                    logger.warning(f"功率表记录工况找到{len(power_tested)}个，少于工况记录单记"
-                                   f"录工况数量{len(self.test_time.keys())}")
-                if len(self.dropped_dcs_cols) > 0:
-                    logger.warning(f"dcs数据中部分列不是数值型数据，已丢弃。"
-                                   f"{json.dumps(self.dropped_dcs_cols, ensure_ascii=False)}｝")
-                self.gather_imp_or_wsn(imp_individual_file)
-                # noinspection all
-                self.yk_signal.emit("eval", "self.progressBar.setValue(33)")
-                self.gather_power(power_individual_file)
-                # noinspection all
-                self.yk_signal.emit("eval", "self.progressBar.setValue(66)")
-                self.gather_dcs(dcs_individual_file)
-                # noinspection all
-                self.yk_signal.emit("eval", "self.progressBar.setValue(100)")
-                self.gather_unknown(unknown_individual_file)
-                # noinspection all
-                self.yk_signal.emit("eval", "self.statusBar().showMessage('就绪')")
-                # noinspection all
-                self.yk_signal.emit("eval", "self.progressBar.setVisible(False)")
-                # noinspection all
-                self.yk_signal.emit("done", "")
-                logger.debug("数据处理完毕！")
-
-            # task_func()
-            # self.table_widget.get_button() # 将按钮置为不可用
             self.table_widget.get_button("自动处理").setEnabled(False)
-            start_threads(targets=task_func)
+            # start_threads(targets=task_func)
+            self.task_func(table)
 
         YkDataTableWidget.choose_file = choose_file  # 向YkDataTableWidget添加两个成员方法，以便其中的按钮绑定事件方法
         YkDataTableWidget.deal = deal
@@ -727,14 +572,169 @@ class MainWindow(YkWindow, QObject):
         self.progressBar.setValue(0)
         self.progressBar.setVisible(False)
 
+    def task_func(self, table):
+        """
+        启动新线程运行耗时较长的方法
+        不能在该线程中创建或修改父线程的GUI元素，如果需要修改GUI，必须使用yk_signal触发QEvent事件调用父线程的方法
+        :return:
+        """
+        folder = table.get_value("目录")
+        self.imp_file = os.path.join(folder, suffix_imp_20 + ".xlsx")
+        self.dcs_file = os.path.join(folder, suffix_dcs_20 + ".xlsx")
+        self.power_file = os.path.join(folder, suffix_p_20 + ".xlsx")
+        self.unknown_file = os.path.join(folder, "unk汇总_修正.xlsx")  # 未识别格式的文件的统计数据
+        self.test_time, self.test_time_file = get_test_time(folder)  # 查询工况记录单
+        logger.debug(f"工况记录单文件为：{self.test_time_file}")
+        number_con = len(self.test_time.keys())
+        logger.info(f"工况记录单中查寻到的工况共{number_con}个！")
+        logger.info(str(list(self.test_time.keys())))
+        dcs_tested = []
+        dcs_individual_file = []  # dcs预处理后的单个储存文件
+        imp_or_wsn_tested = []
+        imp_individual_file = []  # imp数据预处理后的单个储存文件列表
+        power_tested = []
+        power_individual_file = []  # 功率数据预处理后的单个储存文件列表
+        unknown_tested = []
+        unknown_individual_file = []
+        step = 0
+        for file in yield_all_file(folder, [".csv", ".xlsx", ".dat", ".docx", ".txt", ".xls"]):
+            step = step + 1 if step < 100 else 0
+            # self.progressBar.setValue(step)
+            # noinspection all
+            self.progressBar.setValue(step)
+            QApplication.processEvents()
+            # self.yk_signal.emit("eval", "self.progressBar.setValue(" + str(step) + ")")
+            if os.path.splitext(os.path.basename(file))[0].endswith("修正") or "ignore" in os.path.abspath(
+                    file) or "忽略该文件" in os.path.abspath(file):
+                logger.info(f"忽略文件{file}")
+                continue
+            logger.debug(f"处理文件 {file}...")
+            if os.path.splitext(file)[1] == ".xls":
+                # 将xls格式文件另存为csv文件，csv的兼容性最好，然后进行进一步的处理
+                file = save_as_xlsx(file, engine="WPS", ext="xlsx")
+            # 预处理文件，如果文件中包含“时间-数据”条目，则剪切到对应工况的时间段，返回文件类型及剪切后的文件
+            cutting_result = pre_deal_and_cutting_period(file, self.test_time, self.bound, self.config)
+            if cutting_result:
+                if isinstance(cutting_result, tuple) and cutting_result[0] == "power_slice":
+                    power_tested.extend(cutting_result[2])
+                    power_individual_file.extend(cutting_result[1])
+                elif isinstance(cutting_result, tuple) and cutting_result[0] == "imp_slice":
+                    imp_or_wsn_tested.extend(cutting_result[2])
+                    imp_individual_file.extend(cutting_result[1])
+                    self.config.update({"imp_or_wsn_tested": imp_or_wsn_tested})
+                elif isinstance(cutting_result, tuple) and cutting_result[0] == "wsn_slice":
+                    for condition in cutting_result[2]:
+                        file1 = cutting_result[1][
+                            cutting_result[2].index(condition)]  # 找到condition的索引，然后按该索引拿到对应的文件名
+                        if condition in imp_or_wsn_tested:
+                            file2 = imp_individual_file[imp_or_wsn_tested.index(condition)]
+                            data1 = pd.read_csv(file1)
+                            data2: pd.DataFrame = pd.read_csv(file2)
+                            data2, dropped_cols = merge_two_dataframes(data1, data2)
+                            data2[data2 == 0.000] = np.nan
+                            data2.to_csv(file2, index=False)
+                            os.remove(file1)
+                        else:
+                            file2 = os.path.join(os.path.dirname(file1), f"{condition}{suffix_imp_10}.csv")
+                            if os.path.exists(file2):
+                                os.remove(file2)
+                            os.rename(file1, file2)
+                            imp_or_wsn_tested.append(condition)
+                            imp_individual_file.append(file2)
+                elif isinstance(cutting_result, tuple) and cutting_result[0] == "dcs_slice":
+                    # cutting_result[1] 为DCS处理后文件
+                    for condition in cutting_result[2]:
+                        file1 = cutting_result[1][
+                            cutting_result[2].index(condition)]  # 找到condition的索引，然后按该索引拿到对应的文件名
+                        if condition in dcs_tested:
+                            # 如果已经存在当前工况的数据，则合并已有数据和当前数据
+                            file2 = dcs_individual_file[dcs_tested.index(condition)]
+                            data1 = pd.read_csv(file1)
+                            data2 = pd.read_csv(file2)
+                            # 合并两个dataframe，自动判断按行还是按列合并
+                            # 合并的两种情况：
+                            # 1. 两个data的列名相同，但时间段不同，则将data2续到data1的最后一行之后，作为新行
+                            # 2. 两个data的时间段相同，但列名（即参数不同，一般来自DCS系统中导出的不同的趋势组数据）不同，
+                            #    则将data1和data2的列拼接起来。可能还存在更复杂的情况，目前已测试完成。
+                            data2, dropped_cols = merge_two_dataframes(data1, data2)
+                            # data2[data2 == 0.000] = np.nan  # dcs中的数据就有可能全是0，不能替换为np.nan，否则0不显示
+                            self.dropped_dcs_cols = list(set(self.dropped_dcs_cols).union(set(dropped_cols)))
+                            data2.to_csv(file2, index=False)
+                            os.remove(file1)
+                        else:
+                            file2 = os.path.join(os.path.dirname(file1), f"{condition}{suffix_dcs_10}.csv")
+                            # 否则，将当前工况的数据文件名更改为最终数据文件名，并在存在工况列表中添加当前工况
+                            if os.path.exists(file2):
+                                os.remove(file2)
+                            os.rename(file1, file2)
+                            dcs_tested.append(condition)
+                            dcs_individual_file.append(file2)
+                elif isinstance(cutting_result, tuple) and cutting_result[0] == "unk_slice":
+                    for condition in cutting_result[2]:
+                        file1 = cutting_result[1][
+                            cutting_result[2].index(condition)]  # 找到condition的索引，然后按该索引拿到对应的文件名
+                        if condition in unknown_tested:
+                            # 如果已经存在当前工况的数据，则合并已有数据和当前数据
+                            file2 = unknown_individual_file[unknown_tested.index(condition)]
+                            data1 = pd.read_csv(file1)
+                            data2 = pd.read_csv(file2)
+                            data2, dropped_cols = merge_two_dataframes(data1, data2)
+                            # data2[data2 == 0.000] = np.nan  # 有些数如循泵功率一直为0，不能替换为np.nan
+                            data2.to_csv(file2, index=False)
+                            os.remove(file1)
+                        else:
+                            file2 = os.path.join(os.path.dirname(file1), f"{condition}_剪切unk时间_修正.csv")
+                            # 否则，将当前工况的数据文件名更改为最终数据文件名，并在存在工况列表中添加当前工况
+                            if os.path.exists(file2):
+                                os.remove(file2)
+                            os.rename(file1, file2)
+                            unknown_tested.append(condition)
+                            unknown_individual_file.append(file2)
+                elif isinstance(cutting_result, tuple) and cutting_result[0] == "kp_hollysys":
+                    logger.debug("发现和利时点表文件")  # 和利时的点表文件
+                    if self.point_description is None:
+                        self.point_description = cutting_result[1]
+                    else:
+                        self.point_description.update(cutting_result[1])
+
+        self.statusBar().showMessage('汇总试验数据...')
+        self.progressBar.setValue(0)
+        QApplication.processEvents()
+
+        if len(imp_or_wsn_tested) != len(self.test_time.keys()):
+            logger.warning(f"imp采集数据工况找到{len(imp_or_wsn_tested)}个，少于工况记录单记录"
+                           f"工况数量{len(self.test_time.keys())}")
+        if len(power_tested) != len(self.test_time.keys()):
+            logger.warning(f"功率表记录工况找到{len(power_tested)}个，少于工况记录单记"
+                           f"录工况数量{len(self.test_time.keys())}")
+        if len(self.dropped_dcs_cols) > 0:
+            logger.warning(f"dcs数据中部分列不是数值型数据，已丢弃。"
+                           f"{json.dumps(self.dropped_dcs_cols, ensure_ascii=False)}｝")
+        self.gather_imp_or_wsn(imp_individual_file)
+        self.progressBar.setValue(33)
+        QApplication.processEvents()
+        self.gather_power(power_individual_file)
+        self.progressBar.setValue(66)
+        QApplication.processEvents()
+        self.gather_dcs(dcs_individual_file)
+        self.progressBar.setValue(100)
+        QApplication.processEvents()
+        self.gather_unknown(unknown_individual_file)
+        self.statusBar().showMessage('就绪')
+        self.progressBar.setVisible(False)
+        self.yk_signal.emit({"title": "done", "description": ""})
+        if len(self.test_time) == 0:
+            logger.debug(f"未查询到工况记录单文件数据，只进行数据预处理！")
+        logger.debug("数据处理完毕！")
+
     def button_clicked(self):
         sender = self.sender()
         if sender.text() == "保存当前项目":
-            self.config.update({"水位计算点数"     : self.table_widget.get_value("水位计算点数"),
-                                "使用表号确定压力类型" : self.table_widget.get_value("使用表号确定压力类型"),
+            self.config.update({"水位计算点数": self.table_widget.get_value("水位计算点数"),
+                                "使用表号确定压力类型": self.table_widget.get_value("使用表号确定压力类型"),
                                 "未知类型文件区分文件名": self.table_widget.get_value("未知类型文件区分文件名")})
             self.project.update(self.config)
-            writeAsPickle(self.project_file, self.project)
+            write_as_pickle(self.project_file, self.project)
         self.statusBar().showMessage("当前项目已保存")
 
     def post(self, check_box: QCheckBox):
@@ -751,17 +751,12 @@ class MainWindow(YkWindow, QObject):
         if check_box.isChecked():
             self.close()
 
-    @QtCore.pyqtSlot(str, str)
-    def on_message_changed(self, title, description):
-        if title == "progressBar.value":
-            self.progressBar.setValue(int(description))
-        elif title == "statusBar.showMessage":
-            self.statusBar().showMessage(description)
-        elif title == "eval":
-            eval(description)
-        elif title == "done":
+    @QtCore.pyqtSlot(dict)
+    def on_message_changed(self, msg):
+        title = msg.get("title")
+        description = msg.get("description")
+        if title == "done":
             self.table_widget.get_button("自动处理").setEnabled(True)
-            # self.table_widget.setItem(2, 2, QTableWidgetItem("初始化计算数据"))
             btn_init_cal = QPushButton("Analysis")
             q_check_box = QCheckBox("关闭当前界面")
             q_check_box.setChecked(True)
@@ -777,7 +772,7 @@ class MainWindow(YkWindow, QObject):
 
         :return:
         """
-        self.project.update(readFromPickle(self.project_file) or {})
+        self.project.update(read_from_pickle(self.project_file) or {})
         pressure_abs_specific = self.project.get("pressure_abs") or []
         pressure_rel_specific = self.project.get("pressure_rel") or []
         temp_list = pressure_abs_specific.copy()
@@ -819,7 +814,7 @@ class MainWindow(YkWindow, QObject):
         pressure_absolute.extend(pressure_abs_specific)
         pressure_relative.extend(pressure_rel_specific)
         self.project.update(self.config)
-        writeAsPickle(self.project_file, self.project)
+        write_as_pickle(self.project_file, self.project)
 
     def ask_for_absolute_or_relative(self):
         # 查找试验测点中的压力测点是绝压还是表压
@@ -881,7 +876,7 @@ class MainWindow(YkWindow, QObject):
             return
 
         # ===================查找当前处理文件夹中是否存在额外的配置文件，配置文件中是否记录压力测点的信息======================
-        self.project.update(readFromPickle(self.project_file) or {})
+        self.project.update(read_from_pickle(self.project_file) or {})
 
         pressure_rel_specific = self.project.get("pressure_rel") or []
         pressure_abs_specific = self.project.get("pressure_abs") or []
