@@ -10,7 +10,7 @@ from yangke.base import save_as_xlsx, cut_time_period_of_dataframe, get_datetime
     is_contain_chinese, is_datetime, set_dataframe_header, merge_two_dataframes
 from yangke.common import fileOperate
 from yangke.common.config import logger
-from yangke.common.fileOperate import read_csv_ex, writeLines
+from yangke.common.fileOperate import read_csv_ex, write_lines
 from yangke.performance.dp.file_type_detect import get_detailed_type_of_data_file
 from yangke.performance.dp.const_name import suffix_p_10, suffix_dcs_10, suffix_imp_20, suffix_dcs_20, suffix_p_20, \
     suffix_imp_10, suffix_p_01, suffix_dcs_01
@@ -80,7 +80,7 @@ def power_file_pre_deal(file):
         lines = [line[0].replace('"', '') for line in data.iloc[start_line:, :].values]
         outfile1 = os.path.join(os.path.dirname(file),
                                 os.path.splitext(os.path.basename(file))[0] + f"{suffix_p_01}.csv")
-        writeLines(outfile1, lines)
+        write_lines(outfile1, lines)
         data = read_csv_ex(outfile1)
 
         if data.columns[1] == "Date" and data.columns[2] == "Time":
@@ -302,7 +302,11 @@ def dcs2_file_pre_deal(data: pd.DataFrame, file):
     # ---------------------- 将data分割为表头区域的DataFrame和数据区域的DataFrame -------------------------
     title_list = list(set_dataframe_header(title_df)["Description"])
     title_list.insert(0, "DateTime")
-    data_df.set_axis(title_list, axis=1, inplace=True)
+    try:
+        data_df = data_df.set_axis(title_list, axis=1, copy=False)  # 新版本语法
+    except:
+        data_df.set_axis(title_list, axis=1, inplace=True)  # 旧版本语法
+
     data_df.to_csv(outfile, sep=",", index=None)
     return outfile
 
@@ -744,7 +748,7 @@ def pre_deal_and_cutting_period(file, time_dict, bound, config: dict):
             outfile1 = os.path.join(os.path.dirname(file),
                                     os.path.splitext(os.path.basename(file))[0] + suffix_dcs_01 + ".csv")
             lines = fileOperate.read_lines(file, dropna=True)  # 删除文件中的空行，以防pandas出现莫名其妙的问题
-            writeLines(outfile1, lines)
+            write_lines(outfile1, lines)
             start1 = 0
             end1 = 0
             start2 = 0
