@@ -10,7 +10,7 @@ import warnings  # 屏蔽MATPLOTLIBDATA警告
 warnings.filterwarnings("ignore", "(?s).*MATPLOTLIBDATA.*", category=UserWarning)
 
 from yangke.common.config import logger, initLogger
-from yangke.common.fileOperate import write_func, read_func, writeAsPickle, readFromPickle, get_last_modified_time
+from yangke.common.fileOperate import write_func, read_func, write_as_pickle, read_from_pickle, get_last_modified_time
 from yangke.base import Line, interpolate_value_complex
 import os
 from yangke.base import get_settings, plot_3d, get_args, interpolate_2d
@@ -354,7 +354,7 @@ def read_fun_data():
         global coal_consume_2_func
         coal_consume_2_func = read_func("coal_consume_2_func.dat")
         global fl1_range_points
-        fl1_range_points = readFromPickle("fl_range_points.dat")
+        fl1_range_points = read_from_pickle("fl_range_points.dat")
         return True
     except:
         print("未找到函数文件power1_func.dat")
@@ -684,9 +684,9 @@ class MainWindow(YkWindow):
             global power1_func
             num_1_file = self.data_file or r"E:\2020\科研项目\应城电厂热电分配\data.xlsx"
             modified_time = get_last_modified_time(file=num_1_file)
-            modified_time_1 = readFromPickle("last_modified_time.dat")
+            modified_time_1 = read_from_pickle("last_modified_time.dat")
             if modified_time != modified_time_1:
-                writeAsPickle("last_modified_time.dat", modified_time)
+                write_as_pickle("last_modified_time.dat", modified_time)
             # ================================ 加载1号机功率数据==========================================
             logger.debug("加载1号机功率数据")
             # 默认用第一行作为列索引，使用index_col=0设置用第一列作为行索引
@@ -734,7 +734,7 @@ class MainWindow(YkWindow):
                 temp_series = data[:][fm].dropna().index
                 # 因为小数涉及到精度问题，当用其作为字典的键时，最好转换为字符串
                 fl1_range_points.update({str(fm): [temp_series.min(), temp_series.max()]})
-            writeAsPickle("fl_range_points.dat", fl1_range_points)
+            write_as_pickle("fl_range_points.dat", fl1_range_points)
             # ============================== 生成指定中压抽汽量下对应的低压抽汽量的取值范围=================================
 
             # =================================加载1号机煤耗数据===============================================
@@ -1043,7 +1043,7 @@ if __name__ == "__main__":
     else:
         fm1 = float(args.fm1)
         fl_total = float(args.fl_total)
-        data_file = args.data_file
+        data_file = args.exe_file
         if type_cal == "1":
             p2 = float(args.p2)
             assert p2 and fm1 and fl_total
