@@ -4,15 +4,17 @@ import math
 import os.path
 import time
 from datetime import datetime, timedelta
+from enum import Enum
 from typing import Optional
-
+import numpy as np
 import pandas as pd
 
 from yangke.base import merge_two_dataframes, get_settings
-from yangke.common.config import logger
-from yangke.core import runCMD
+from yangke.core import runCMD, str_in_list
 
 
+# 该模块不能引入from yangke.common.config import logger，否则会导致命令行写SIS无限生成log文件
+
 def ctypes_str2char_array(string: str):
     """
     python3中的字符串是以utf-8格式编码的，为了将字符串传递给C函数，需要将其解码为byte类型，对应C函数中的char*类型或char[]类型
@@ -42,7 +44,7 @@ def init_write_sis(ip=None, user=None, passwd_str=None, port=None):
         line = line.replace("%python_exec%", path)
         line = line.replace("%py_file%", os.path.abspath(temp_write_sis_py))
         lines_new.append(line)
-    fo.writeLines(temp_write_sis_bat, lines_new)
+    fo.write_lines(temp_write_sis_bat, lines_new)
     if ip is not None and user is not None and passwd_str is not None and port is not None:
         lines = fo.read_lines(write_sis_py)
         lines_new = []
@@ -53,7 +55,7 @@ def init_write_sis(ip=None, user=None, passwd_str=None, port=None):
             line = line.replace('@port@', str(port))
             lines_new.append(line)
 
-        fo.writeLines(temp_write_sis_py, lines_new)
+        fo.write_lines(temp_write_sis_py, lines_new)
 
 
 def init_dbp_api(settings=None, ip=None, port=None, user=None, password=None):
@@ -67,12 +69,18 @@ def init_dbp_api(settings=None, ip=None, port=None, user=None, password=None):
     :param password:
     :return:
     """
+    from yangke.common.config import logger
+
     if settings is None:
         settings = get_settings()
     _ip = settings.get_settings("sis.ip")
+    _ip = None if _ip == {} else _ip
     _port = settings.get_settings("sis.port")
+    _port = None if _port == {} else _port
     _user = settings.get_settings("sis.user")
+    _user = None if _user == {} else _user
     _password = settings.get_settings("sis.password")
+    _password = None if _password == {} else _user
 
     ip = _ip if _ip is not None else ip
     port = _port if _port is not None else port
@@ -89,7 +97,7 @@ def init_dbp_api(settings=None, ip=None, port=None, user=None, password=None):
 
 def read_data(tag_des_read, need_detail=False):
     """
-    读取标签数据，返回以描述为表头的dataframe对象
+    读取标签数据，返回以描述为表头的dataframe对象，从settings.yaml中加载代理服务器信息
 
     当tag_des_read为字典时示例如下：
     tag_heat_supply_read = {"N1DCS.TOTALMW": "#1电功率", "N2DCS.TOTALMW": "#2电功率", "N3DCS.TOTALMW": "#3电功率"}
@@ -111,6 +119,8 @@ def read_data(tag_des_read, need_detail=False):
     :param need_detail:
     :return:
     """
+    from yangke.common.config import logger
+
     dbp_api = init_dbp_api()
     if dbp_api is not None:
         if not isinstance(tag_des_read, dict):
@@ -141,6 +151,8 @@ class DllMode:
             self.handle: Optional[ctypes.c_uint64] = None
             self.dll = ctypes.cdll.LoadLibrary(path)
         except OSError:
+            from yangke.common.config import logger
+
             logger.warning(f"找不到指定的动态链接库！请检查路径{path}")
             raise OSError(f"找不到指定的动态链接库！请检查路径{path}")
         if ip is not None and user is not None and passwd_str is not None and port is not None:
@@ -357,10 +369,14 @@ class DllMode:
     def write_snapshot_by_cmd(self, tags, values):
         """
         该方法功能和self.write_snapshot_double()完全相同，但是将写入操作重启一个进程进行，这样写入操作报错时，不会影响主程序崩溃。
+        如果出现“Python已停止工作”错误，请检查RDBProxy代理和数据库中是否存在相关的测点。
+
         :param tags:
         :param values:
         :return:
         """
+        from yangke.common.config import logger
+
         for k in tags:
             if k is None:
                 logger.error("标签列表中存在空标签，请检查测点名")
@@ -388,7 +404,8 @@ class DllMode:
 
     def write_snapshot_double(self, tags, values):
         """
-        写double类型数据到数据库，该方法可能会导致程序异常退出，建议使用第三方exe独立调用该接口
+        写double类型数据到数据库，该方法可能会导致程序异常退出，建议使用第三方exe独立调用该接口。
+        如果出现“Python已停止工作”错误，请检查RDBProxy代理和数据库中是否存在相关的测点。
 
         :param tags: 标签名列表
         :param values: 数值列表
@@ -427,3 +444,204 @@ class DllMode:
             pass
 
 
+def get_tag_value(snapshot, tag_description, optional_value=0):
+    """
+    根据标签描述获取快照中的数据
+
+    :param snapshot:
+    :param tag_description:
+    :param optional_value: 标签不存在时的替代值，也就是默认值
+    :return:
+    """
+    if isinstance(tag_description, Enum):  # 枚举类的对象
+        tag_description = tag_description.name
+
+    if isinstance(snapshot, dict):
+        result = snapshot.get(tag_description)
+    else:
+        try:
+            result = snapshot[tag_description][0]
+            if isinstance(result, np.int64):
+                result = None
+            else:
+                result = float(snapshot[tag_description][0])
+        except KeyError:
+            print(f"快照中不包括名为[{tag_description}]的变量，返回None")
+            result = None
+    if result is None:
+        result = optional_value
+    return result
+
+
+class ColdResult:
+    def __init__(self):
+        """
+        冷端优化的结果类，使用方法实力：
+        # 初始化设置，只需执行一次
+        cold_result = ColdResult()
+        cold_result.设置允许的运行参数波动范围(allowed_range)
+        cold_result.设置背压标签(["背压1", "背压2"])
+        cold_result.设置冷端功率标签(["冷端总功率1", "冷端总功率2"])
+        cold_result.设置状态参数标签()
+
+        # 每次优化结果更新时
+        cold_result.pass_result(result_opt)
+        cold_result.平抑波动()
+        result_opt = cold_result.opt_result
+
+        其中，pass_result方法中传入的参数一般应包括：循泵、风机等最佳运行方式，当前实际的发电机功率、背压、环境温度、湿度、大气压力等
+        """
+        self.allowed_range = None  # 允许的参数波动范围，当机组运行状态在该范围内波动时，冷端优化结果不更新，该值示例如下，只与对象有关
+        # [("电功率1", "±2"), ("供热流量", "±4"),("环境温度", "±4"), ("大气压力", "±10")]
+        self.allowed_range_dict = {}  # {"电功率": [34, 38], "供热流量": [54, 62], ...}该值是变量，随时间变化
+        self.last_state = None
+        self.now_state = {}  # 当前时刻机组的实际运行参数
+        self.opt_result = {}  # 当前时刻机组的优化后冷端优化结果
+        self.bp_label = []  # 背压参数在数据集中的列标签名，一般就是"背压"，但对于全场优化，可能有多个背压参数，以列表方式传入
+        self.state_labels = []  # 状态参数在数据集中的列表签名，一般为["电功率", "供热量", "环境温度"]
+        self.p_cold_label = None  # 冷端总功率在数据集中的列标签名
+        self.last_opt_result = None  # 最后一个状态中的优化结果值
+        self.last_true_state = None  # 最后一个状态中的实际状态值
+
+    def 设置允许的运行参数波动范围(self, range=[]):  # todo
+        """
+        设置允许的参数波动范围，示例：
+        cold_result = ColdResult()
+        allowed_range = [("电功率1", "±2"), ("供热流量", "±4"),("环境温度", "±4"), ("大气压力", "±10")]
+        cold_result.设置允许的运行参数波动范围(allowed_range)
+        allowed_range中的键必须存在于self.pass_result()方法的true_state字典中。即allowed_range中有“电功率1”，则true_state参数也
+        必须有"电功率1"。
+
+        :param range:
+        :return:
+        """
+        self.allowed_range = range
+
+    def 设置背压标签(self, label):
+        if isinstance(label, list):
+            self.bp_label = label
+        else:
+            self.bp_label = [label]
+
+    def 设置冷端功率标签(self, label):
+        self.p_cold_label = label
+
+    def 设置状态参数标签(self, labels):
+        if isinstance(labels, list):
+            self.state_labels = labels
+        else:
+            self.state_labels = [labels]
+
+    def pass_result(self, opt_result={}, true_state={}):
+        """
+        传入新的冷端优化结果，并根据冷端功率大小调节背压大小以符合客观规律。
+
+        :param opt_result: 当前时刻的原始优化结果
+        :param true_state: 当前时刻的运行值，至少包含电功率、供热、环境以及冷端运行方式等参数
+        :return:
+        """
+        self.last_opt_result = self.opt_result
+        self.last_true_state = self.now_state
+        self.now_state = true_state  # 当前时刻的运行值
+        self.opt_result = opt_result
+
+    def 背压合理化调整(self):
+        def cal_dp(凝汽器热负荷, 冷端电功率变化, 环境温度):
+            """
+            计算背压变化值，背压变化与机组负荷、供热流量以及冷端设备运行方式有关
+
+            :param power:
+            :param heat:
+            :param dpower:
+            :return:
+            """
+            ...
+
+        opt_result = self.opt_result
+        true_state = self.now_state
+        for bpl in self.bp_label:
+            if opt_result[bpl] == 0:  # 如果停机状态
+                continue
+            else:
+                _ = true_state[bpl] * (true_state[self.p_cold_label] / opt_result[self.p_cold_label])
+                背压差 = abs(_ - true_state[bpl])
+            if opt_result[bpl] < true_state[bpl]:
+                opt_result[bpl] = true_state[bpl] + 背压差
+            else:
+                opt_result[bpl] = true_state[bpl] - 背压差
+        self.opt_result = opt_result
+
+    # def _get_allowed_range(self):
+
+    def _get_allowed_range_str(self, title):
+        for item in self.allowed_range:
+            if item[0] == title:
+                return item[1]
+
+    def 平抑波动(self, unit=None):
+        """
+        当机组参数波动较小时，不改变冷端运行方式。
+
+        参数判断分机组进行还是全厂一起进行，当unit值为None时，全厂整体平抑波动，如果需要分机组平抑波动，通过该值传入机组标号，如[1,2]。
+        如果是分机组平抑波动，则self.opt_result中变量的最后一个字符需要与机组编号对应，如"power1"表示1号机组的参数。
+
+        :param unit: 参数判断分机组进行还是全厂一起进行
+        :return:
+        """
+
+        def get_min_max_value(val, range_str):
+            # 根据当前值和表示范围的字符串，计算允许的参数的上下限的值
+            if range_str.startswith("±"):
+                _r = float(range_str[1:])
+                min_val = val - _r
+                max_val = val + _r
+            elif range_str.endswith("%"):
+                pass
+            return min_val, max_val
+
+        need_update = False  # 是否需要更新画面上的优化结果，如果参数波动小，则不更新，否则，更新
+        if unit is None:
+            for item in self.allowed_range:
+                title, range = item
+                if self.last_true_state.get(title) is None:  # 历史数据不存在，则认为满足小幅波动范围，直接更新优化结果为当前计算结果
+                    need_update = True
+                    break
+                if not self.allowed_range_dict[title][0] <= self.now_state[title] <= self.allowed_range_dict[title][1]:
+                    need_update = True
+                    break
+
+            if need_update:  # 如果需要更新优化结果，更新新的允许的参数波动范围
+                for item in self.allowed_range:
+                    title, range = item
+                    val = self.now_state[title]
+                    min_val, max_val = get_min_max_value(val, range)
+                    self.allowed_range_dict.update({title: [min_val, max_val]})
+            else:  # 如果波动幅度小，则不需要更新优化结果，直接返回上一次优化结果
+                self.opt_result = self.last_opt_result
+        else:
+            for u in unit:
+                for item in self.allowed_range:
+                    title, _range = item
+                    if title.endswith(str(u)):
+                        if self.last_true_state.get(title) is None:
+                            need_update = True
+                            break
+                        if not self.allowed_range_dict[title][0] <= self.now_state[title] <= \
+                               self.allowed_range_dict[title][1]:
+                            need_update = True
+                            break
+                if need_update:
+                    for item in self.allowed_range:
+                        title, _range = item
+                        if title.endswith(str(u)):  # 只限制运行方式，不限制背压
+                            val = self.now_state[title]
+                            min_val, max_val = get_min_max_value(val, _range)
+                            self.allowed_range_dict.update({title: [min_val, max_val]})
+                        # 如果需要更新，则维持现有的opt_result结果不变
+                else:
+                    for k, v in self.opt_result.items():
+                        if k.endswith(str(u)) and not str_in_list(k, self.bp_label):  # 优化后背压仍取实时值
+                            self.opt_result.update({k: self.last_opt_result.get(k)})
+
+    def get_result(self):
+        return self.opt_result
