@@ -4,21 +4,29 @@ import os
 import time
 from datetime import date
 import logging  # 日志输出
+
+from sqlalchemy import create_engine, DATE, BOOLEAN, Float
+from sqlalchemy.engine import Engine
+
 import yangke.stock.globalVar as gv
 
 import numpy as np
 import pandas as pd
 # import talib  # 下载不成功
 import tushare as ts  # 股票数据下载
-import json5
 import yangke.common.config as config
-from yangke.common.mysql import select_in_table, cursor2engine, dtype_dict, update_update_time_of_table
+from yangke.common.config import logger
+from yangke.dataset.mysql import select_in_table, update_update_time_of_table
 from threading import Thread
 import traceback
 import copy
-from yangke.common.mysql import insert_item_to_mysql, insert_dataframe_to_mysql, start_mysql_service, \
-    read_dataframe_from_mysql, get_update_time_of_table, has_table, create_table
+from yangke.dataset.mysql import insert_item_to_mysql, insert_dataframe_to_mysql, read_dataframe_from_mysql, \
+    get_update_time_of_table, \
+    create_table
 from yangke.base import merge_two_dataframes
+from yangke.dataset.sqlalchemy import SqlOperator, YkColumn
+from yangke.dataset.sqlalchemy import Base, Column, String, DATETIME
+from yangke.stock.DatasetClass import Holiday
 
 
 class StockData:
@@ -26,68 +34,80 @@ class StockData:
     初始化tushare，填写token
     """
 
-    def __init__(self, data_dir: str, code: str = None, day=date.today(), mysql_engine=None):
+    def __init__(self, project=None):
         super().__init__()
         self.api = ts.pro_api('67e4202fb31f321f28929afdbe11780241cd35eb662f6f1947f7e800')
         # --------------全局参数-----------------
-        self.dataDir = data_dir
-        self.code = code
-        self.day = day
-        self.encode = gv.encoding
-        self.conn = mysql_engine
-        if self.conn is None:  # 如果传入了非空的数据库连接，则使用mysql数据库存储股票数据，否则使用本地文件存储数据
-            self.storage = "file"
-        else:
-            self.storage = "mysql"
+        if project is not None:
+            self.data_folder = project.data_folder or "stock_data"
+            self.code = project.symbol
+            self.storage = project.storage
+            self.encoding = project.encoding
+            self.project = project
+        self.engine: Engine | None = None
+        self.股票信息表 = "AllStocksBasicInfo"
+        self.sql: SqlOperator | None = None  # SqlOperator()  # 使用时初始化
 
     def __repr__(self):
-        info = "dataDir={}, code={}, day={}, encoding={}".format(self.dataDir, self.code, self.day, self.encode)
+        info = f"股票数据类"
         return info
 
+    def __getstate__(self):
+        """
+        自定义的类型，实现该方法后，则可以使用pickle进行序列化与反序列化
+        """
+        return {"data_folder": self.data_folder, "code": self.code, "day": self.day, "storage": self.storage}
+
     def setCode(self, code: str):
         self.code = code
 
     def setDay(self, day: datetime.date):
         self.day = day
 
-    def get_name(self):
-        # df = api.query('daily', ts_code='000001.SZ')
-        # df.to_csv('000001.csv', columns=['trade_date', 'open', 'high', 'low', 'close', 'vol'])
+    def get_name(self, code):
         data = self.api.stock_basic(exchange='', list_status='L', fields='ts_code,symbol,name,area,industry,list_date')
 
-        data_s = data[data['symbol'] == self.code]  # 选出‘symbol=600006'的那一行，成为1行n列的DataFrame数据
+        data_s = data[data['symbol'] == code]  # 选出‘symbol=600006'的那一行，成为1行n列的DataFrame数据
 
         name = data_s.iloc[0, 2]  # 选出第0行第2列，因为数据经过挑选只有一行，所以行号永远为0
-        print("debug: name|" + name)
         return name
 
-    def get_all_stock_symbol(self) -> list:
+    def get_ts_code_by_symbol(self, symbol):
+        """
+        根据股票的symbol获取ts_code
+        """
+        res = self.sql.select_in_table(table_name='AllStocksBasicInfo',
+                                       condition_dict={"symbol": symbol},
+                                       result_col="ts_code")
+        if res is None:
+            self.get_all_stock_basic_info()
+            res = self.sql.select_in_table(table_name='AllStocksBasicInfo',
+                                           condition_dict={"symbol": symbol},
+                                           result_col="ts_code")
+            if res is None:
+                logger.warning(f"不存在代码为{symbol}的股票，请检查！")
+        return res
+
+    def get_all_stock_basic_info(self) -> pd.DataFrame:
         """
         获得上海和深圳证券交易所目前上市的所有股票代码
 
         :return: 股票代码的列表
         """
-        if self.storage == "file":
-            symbol_file = os.path.join(self.dataDir, "allsymbols.json")
-            if self.need_update(symbol_file):  # 如果需要更新
-                inner_data = self.api.stock_basic(exchange='', list_status='L', fields='symbol')
+        self.init_storage()
+        if self.storage == "Sqlite数据库":
+            update_time = self.sql.get_update_time_of_table(self.股票信息表)
+            if self.need_update(update_time):  # 如果需要更新
+                inner_data = self.api.stock_basic(exchange='', list_status='L',
+                                                  fields=['ts_code', 'symbol', 'name', 'area', 'industry', 'market',
+                                                          'list_date'])
                 inner_data = inner_data.sort_values(by='symbol', ascending=True)
-                inner_data.to_json(symbol_file)
-                in_symbols = inner_data['symbol']  # 股票symbol的series，symbols[0]是第一只股票，symbols[-1]是最后一只股票
+                # 保存到Sqlite数据库
+                inner_data.to_sql(name=self.股票信息表, con=self.engine, if_exists="replace", index=False)
+                self.sql.update_update_time_of_table(self.股票信息表)
             else:
-                in_symbols = pd.read_json(symbol_file, encoding=self.encode, dtype=str)['symbol']
-            return list(in_symbols)
-        else:
-            update_time = get_update_time_of_table("symbols")
-            if self.need_update(update_time):
-                inner_data = self.api.stock_basic(exchange='', list_status='L', fields='symbol,name')
-                inner_data: pd.DataFrame = inner_data.sort_values(by='symbol', ascending=True)
-                inner_data.to_sql("symbols", con=self.conn, if_exists='replace', index=False)  # pd.to_sql会直接替换表
-                in_symbols = inner_data['symbol']  # 股票symbol的series，symbols[0]是第一只股票，symbols[-1]是最后一只股票
-                update_update_time_of_table("symbols")
-            else:
-                in_symbols = read_dataframe_from_mysql("symbols")['symbol']
-            return list(in_symbols)
+                inner_data = pd.read_sql(sql=self.股票信息表, con=self.engine)
+            return inner_data
 
     @config.loggingTitleCall(title="查看触底反弹股")
     def get_bottom_out(self, in_recent_days: int = 10):  # 触底反弹股票，根据近30天内的数据进行判断
@@ -111,8 +131,8 @@ class StockData:
                 # print(row['ts_code'])
                 inner_symbols.append(inner_row['ts_code'])
                 symbols_first.append(inner_row['ts_code'])
-        gv.logger.debug("初筛触底反弹股列表:{}".format(symbols_first))
-        gv.logger.debug("进一步检查初筛列表...")
+        logger.debug("初筛触底反弹股列表:{}".format(symbols_first))
+        logger.debug("进一步检查初筛列表...")
         # 进一步删选选出来的股票，剔除其中最低价没有出现在最后一天的股票，只有最后一天是最低价，才能算是触底反弹
         for inner_symbol in symbols_first:
             df = self.download(inner_symbol, append=True)
@@ -124,7 +144,7 @@ class StockData:
                 pass
             else:
                 inner_symbols.remove(inner_symbol)
-        gv.logger.debug("触底反弹股列表:{}".format(inner_symbols))
+        logger.debug("触底反弹股列表:{}".format(inner_symbols))
         return inner_symbols, symbols_first
 
     def download_all_stocks(self, codes: list = None, num_works=64, exclude: list = None) -> list:
@@ -149,8 +169,8 @@ class StockData:
             state = gv.RunState().load()
             if not self.need_update(state.last_update_time):
                 return state.stocks
-            codes_available = self.get_all_stock_symbol()
-            gv.logger.debug("下载沪深所有股票数据，预计耗时10分钟左右（本地所有股票数据需要更新时）...")
+            codes_available = self.get_all_stock_basic_info()
+            logger.debug("下载沪深所有股票数据，预计耗时10分钟左右（本地所有股票数据需要更新时）...")
         else:
             codes_available = codes
         if exclude is not None:
@@ -191,12 +211,12 @@ class StockData:
 
             codes_available.sort()  # 默认升序
         except:
-            gv.logger.error("multi-process error!")
+            logger.error("multi-process error!")
             traceback.print_exc()  # 打印系统错误提示
             import sys
             sys.exit(1)
 
-        gv.logger.info("All stock data downloaded, finish")
+        logger.info("All stock data downloaded, finish")
         if codes is None:  # 如果下载了所有的股票，就记录最后更新时间
             state = gv.RunState(last_update_time=datetime.datetime.now(), stocks=codes_available)
             state.dump()  # 序列化后使用state=gv.RunState().load()可以加载回来
@@ -216,91 +236,77 @@ class StockData:
 
         :param code: 股票代码，可以带证交所后缀的股票代码：如601002.SH，也可以只是股票编号：601002
         :param append: 如果为True，则追加新数据到已有数据，而不是下载后替换已有数据
-        :param to_mysql: 是否使用mysql数据库存储，如果为False，则存储为本地csv文件
         :return:
         """
         code = str(code)
-        gv.logger.debug("准备下载股票数据，股票代码：" + code)
+        logger.debug("准备下载股票数据，股票代码：" + code)
         if '.' in code:  # 如果传入的股票代码是类似于 000544.SZ 格式的，则去掉后面的 .SZ,只保留数字格式代码
-            code = code[0:6]
-
-        if self.storage == "mysql":
-            update_time = get_update_time_of_table(f"basic{code}")
-            if not self.need_update(update_time):
-                gv.logger.debug("本地数据已是最新，使用本地股票数据（读取自mysql数据库）...")
-                df = read_dataframe_from_mysql(f"basic{code}")
-                return df
+            ts_code = code
+            symbol = code[0:6]
         else:
-            if not os.path.exists(self.dataDir):
-                os.mkdir(self.dataDir)
-            inner_data_file = os.path.join(self.dataDir, code + '.csv')  # 数据存储时会覆盖，所以不用删除当前已存在的数据文件
-            if not self.need_update(inner_data_file):  # 判断是否需要更新数据，无需更新则直接返回
-                gv.logger.debug("本地数据已是最新，使用本地股票数据（%s）..." % inner_data_file)
-                df = pd.read_csv(inner_data_file, encoding=self.encode)
+            ts_code = self.get_ts_code_by_symbol(code)
+            symbol = code
+
+        if self.storage == "Sqlite数据库":
+            update_time = self.sql.get_update_time_of_table(f"daily{symbol}")
+            if not self.need_update(update_time):
+                logger.debug(f"本地数据已是最新，使用本地股票数据（读取自{self.storage}）...")
+                df = pd.read_sql(f"daily{symbol}", con=self.engine)
                 return df
+
         # 如果需要更新，则开始更新
-        gv.logger.debug("本地数据需要更新，开始下载股票数据（%s）..." % code)
+        logger.debug("本地数据需要更新，开始下载股票数据（%s）..." % code)
         success = False  # 标记是否成功下载
         try:
-            df = ts.get_hist_data(code)  # ts.get_hist_data('600848',start='2015-01-05',end='2015-01-09')
+            df = self.api.query('daily', ts_code=ts_code)
             if df is None:  # 有时候下载失败，会导致df为None，如果出现这种情况，重复10次
-                gv.logger.debug("下载股票数据{}失败，重试...".format(code))
+                logger.debug(f"下载股票数据{symbol}失败，重试...")
                 for i in range(10):
-                    df: pd.DataFrame = ts.get_hist_data(code)
+                    df: pd.DataFrame = self.api.query('daily', ts_code=ts_code)
                     if df is not None:
                         success = True
-                        gv.logger.debug("下载股票数据{}失败，重试...，成功！".format(code))
+                        logger.debug(f"下载股票数据{symbol}失败，重试...，成功！")
                         break
             else:
                 success = True
         except:  # 当网络故障的时候，ts.get_hist_data(code)会报错
-            gv.logger.error("获取股票{}失败，请检查网络".format(code))
+            logger.error(f"获取股票{symbol}失败，请检查网络")
             return None
         if not success:
-            gv.logger.warning("经过10次尝试后，下载股票数据{}一直失败，没有数据"
-                              "保存到本地！停牌超过两年或预上市股票也会产生该警告！".format(code))
+            logger.warning(f"经过10次尝试后，下载股票数据{code}一直失败，没有数据"
+                           "保存到本地！停牌超过两年或预上市股票也会产生该警告！")
             return None
         df.sort_index(inplace=True)  # 反序排列数据，这样让更新的数据位于文件最下方
         df.reset_index(inplace=True)
-        df = df[['date', 'open', 'high', 'close',
-                 'low', 'volume', 'price_change',
-                 'p_change']]
+
+        # vol: 成交量(手), amount: 成交额(千元)
+        df = df[['trade_date', 'open', 'high', 'low', 'close', 'vol', 'amount']]
+        df['trade_date'] = pd.to_datetime(df["trade_date"])  # df中的数据转换成时间列
         if append:  # 如果需要追加数据
-            if self.storage == "mysql":
-                # 建议使用df.to_sql()之前先创建表，因为df.to_sql()方法默认建的表数据类型及primary key都难以控制
-                if not gv.mysql_engine.has_table(f"basic{code}"):  # 不存在就创建
-                    create_table(table_name=f"basic{code}", columns={
-                        'date': "date",
-                        'open': "float",
-                        "high": "float",
-                        "close": "float",
-                        "low": "float",
-                        "volume": "float",
-                        "price_change": "float",
-                        "p_change": "float"
-                    }, primary=[0])
-                insert_dataframe_to_mysql(table_name=f"basic{code}",
-                                          dataframe=df, ignore=True)
-                # 手动更新mysql表的更新时间
-                update_update_time_of_table(f"basic{code}")
-                # 使用df.to_sql当df数据与现有表中有数据相同时，会报错。
-                # df.to_sql(f"basic{code}", con=gv.mysql_engine, if_exists="append", index=False)
+            if self.storage == "Sqlite数据库":
+                if not self.sql.has_table(f"daily{symbol}"):  # 不存在就创建
+                    self.sql.create_table(table_name=f"daily{symbol}",
+                                          columns=[
+                                              YkColumn('trade_date', DATE(), primary_key=True),
+                                              YkColumn('open', Float()),
+                                              YkColumn('high', Float()),
+                                              YkColumn('low', Float()),
+                                              YkColumn('close', Float()),
+                                              YkColumn('vol', Float()),
+                                              YkColumn('amount', Float()),
+                                          ])
+
+                    df.to_sql(name=f"daily{symbol}", con=self.engine,
+                              index=False, if_exists="replace",
+                              dtype={
+                                  'trade_date': DATE,
+                              })
+                    # 手动更新mysql表的更新时间
+                    self.sql.update_update_time_of_table(f"daily{symbol}")
             else:
                 # noinspection all
-                if os.path.exists(inner_data_file):  # 如果本地存在
-                    df_exists = pd.read_csv(inner_data_file, encoding=self.encode)  # 读取本地存在的数据
-                    df, _ = merge_two_dataframes(df, df_exists)
+                logger.debug("不支持本地存储")
 
-        if self.storage == "mysql":
-            # 存储到mysql数据库
-            gv.logger.debug(f"股票数据存储在mysql数据库stocks > basic{code}表中")
-            df = read_dataframe_from_mysql(f"basic{code}")
-        else:
-            df.to_csv(inner_data_file, index=False, encoding=self.encode, columns=['date', 'open', 'high', 'close',
-                                                                                   'low', 'volume', 'price_change',
-                                                                                   'p_change'])
-            # 我们需要日期列的内容，因此需要重新读取一边csv文件
-            gv.logger.debug("股票%s数据存储在%s" % (code, inner_data_file))
         return df
 
     def download_daily(self, day_datetime: datetime.date):
@@ -317,27 +323,27 @@ class StockData:
             hour = time.strftime("%H")
             if int(hour) < 16:  # 更新时间：交易日每天15点～16点之间，所以需要16点以后调用保证正确性，16点以前调用获得的是上一个交易日的数据
                 day_datetime = self.get_working_day_before_day(day_datetime, 1)
-                gv.logger.debug("正常交易日，16:00之前当日数据尚未更新，使用上一个交易日的数据！")
+                logger.debug("正常交易日，16:00之前当日数据尚未更新，使用上一个交易日的数据！")
             else:
-                gv.logger.debug("正常交易日，使用本日数据！")
+                logger.debug("正常交易日，使用本日数据！")
         else:
-            gv.logger.debug("今天休市，使用上一个交易日的数据！")
+            logger.debug("今天休市，使用上一个交易日的数据！")
 
         day_str = day_datetime.strftime("%Y%m%d")
-        gv.logger.debug("准备交易日数据，日期：{}".format(day_datetime))
+        logger.debug("准备交易日数据，日期：{}".format(day_datetime))
         # ------------创建“api_daily/日期.csv”用以保存数据-----------
-        parent_path1 = os.path.join(self.dataDir, 'api_daily')
+        parent_path1 = os.path.join(self.data_folder, 'api_daily')
         if not os.path.exists(parent_path1):
             os.mkdir(parent_path1)
         data_file = os.path.join(parent_path1, day_str + '.csv')
         # ------------创建“api_daily/日期.csv”用以保存数据-----------
         if not self.need_update(data_file):
             df = pd.read_csv(data_file, encoding=self.encode)
-            gv.logger.debug("检查本地数据：存在数据文件且无需更新，使用本地数据")
+            logger.debug("检查本地数据：存在数据文件且无需更新，使用本地数据")
         else:
             df = self.api.daily(trade_date=day_str)  # 真正获得数据
             df.to_csv(data_file, encoding=self.encode, index=False)
-            gv.logger.debug("检查本地数据：本地数据文件不存在或需要更新，下载交易日数据...")
+            logger.debug("检查本地数据：本地数据文件不存在或需要更新，下载交易日数据...")
         return df
 
     def get_data_of_day(self, code, day_datetime: date = date.today(), next_day: int = -1):
@@ -361,13 +367,13 @@ class StockData:
                 return self.get_data_of_day(code, day_datetime, -1)
             else:
                 day_datetime = self.get_working_day_before_day(day_datetime, -1)  # 获得后一个工作日
-                last_datetime = datetime.datetime.strptime(str(self.get_previous_working_day(includeTime=True)),
+                last_datetime = datetime.datetime.strptime(str(self.get_previous_working_day(include_time=True)),
                                                            '%Y-%m-%d')  # 目前为止最后一个有数据的交易日
                 if day_datetime >= last_datetime:  # 如果后一个工作日在今天(有数据的股票交易日)之前
                     return self.get_data_of_day(code, day_datetime, 1)  # 因为这里day_datetime必然是工作日，因此第三个参数
                     # 一般是不重要的，给了1是为了防止指定股票在当日停牌，这种情况极少见
                 else:
-                    gv.logger.error("指定日期{}的股票数据不存在，检查日期是否是未来的日期！".format(day_datetime))
+                    logger.error("指定日期{}的股票数据不存在，检查日期是否是未来的日期！".format(day_datetime))
                     # 这种情况目前不存在用例，将来在设计返回参数
         return df
 
@@ -382,7 +388,7 @@ class StockData:
         """
         # <<<<<<<<<<<<<<<<<<<<<方法1-----------------------------------------
         dates = []
-        day = self.get_previous_working_day(last_date, includeTime=True)  # 获得指定日期前的最后一个交易日
+        day = self.get_previous_working_day(last_date, include_time=True)  # 获得指定日期前的最后一个交易日
         while len(dates) < n:
             dates.append(day)
             day = self.get_working_day_before_day(day)
@@ -392,7 +398,7 @@ class StockData:
         elif sort.lower() == 'descend':
             pass
         else:
-            gv.logger.error("参数sort未识别，sort只能取值'ascend'和'descend'!")
+            logger.error("参数sort未识别，sort只能取值'ascend'和'descend'!")
         return dates
 
     def need_update(self, data_file: str or datetime.datetime):
@@ -421,23 +427,23 @@ class StockData:
 
         if last_change_date_str == now_time_date_str:  # 如果是今天修改的
             if last_change_time.hour > 15:  # 最后修改日期是当天15点以后，则不用更新数据
-                gv.logger.debug("数据文件{}已经最新，无需更新！".format(data_file))
+                logger.debug("数据文件{}已经最新，无需更新！".format(data_file))
                 return False  # 无需更新数据
             else:
                 if now_time.hour < 16:  # 如果今天修改过且今天还没到16:00，也无须更新
                     return False
                 # 如果今天时holiday
                 if self.is_holiday(date.today()):  # 如果今天时休息日，今天更新过也不用更新
-                    gv.logger.debug("数据文件{}已经最新，无需更新！".format(data_file))
+                    logger.debug("数据文件{}已经最新，无需更新！".format(data_file))
                     return False
                 else:
                     return True
         else:
-            last_working_day_str = str(self.get_previous_working_day(includeTime=True)) + ' 16:00:00'
+            last_working_day_str = str(self.get_previous_working_day(include_time=True)) + ' 16:00:00'
             last_working_datetime = datetime.datetime.strptime(last_working_day_str, '%Y-%m-%d %H:%M:%S')
             if last_change_time > last_working_datetime:
                 # 如果最后修改日期在上一个工作日15点之后
-                gv.logger.debug("数据文件{}已经最新，无需更新！".format(data_file))
+                logger.debug("数据文件{}已经最新，无需更新！".format(data_file))
                 return False  # 无需更新数据
             else:
                 return True
@@ -456,10 +462,10 @@ class StockData:
         elif up_down.lower() == 'down':
             title = "跌停"
         else:
-            gv.logger.debug("参数未识别，up_down只能取值'up'或'down'！")
+            logger.debug("参数未识别，up_down只能取值'up'或'down'！")
         config.loggingTitle("查找开盘{}股({})".format(title, day_datetime), "start")
         open_limit = self._get_limit(up_down=up_down, day_datetime=day_datetime)
-        gv.logger.debug("开盘{}股列表:{}".format(title, open_limit))
+        logger.debug("开盘{}股列表:{}".format(title, open_limit))
         config.loggingTitle("查找开盘{}股({})".format(title, day_datetime), "end")
         return open_limit
 
@@ -481,31 +487,33 @@ class StockData:
         # ------------把day由"%Y-%m-%d"转为"%Y%m%d"格式-----------
 
         # ------------创建“api_daily/日期.csv”用以保存数据-----------
-        parent_path1 = os.path.join(self.dataDir, 'api_daily')
+        parent_path1 = os.path.join(self.data_folder, 'api_daily')
         if not os.path.exists(parent_path1):
             os.mkdir(parent_path1)
         data_file = os.path.join(parent_path1, day_str + '.csv')
         # ------------创建“api_daily/日期.csv”用以保存数据-----------
         if os.path.exists(data_file):  # 因为data_file是以日期命名的，存在就不需要更新
             # 判断数据是否有变化
-            df = pd.read_csv(data_file, encoding=self.encode)
+            df = pd.read_csv(data_file, encoding=self.encoding)
         else:
             df = self.api.daily(trade_date=day_str)  # 真正获得数据
-            df.to_csv(data_file, encoding=self.encode, index=False)
+            df.to_csv(data_file, encoding=self.encoding, index=False)
         df = np.array(df)
         for stock in df:  # 判断每一只股票
             # 开盘涨/跌停股票开盘/收盘/最高/最低价都是相同的
             if stock[2] == stock[3] == stock[4] == stock[5]:
                 if up_down.lower() == "up":
                     if (stock[2] - stock[6]) / stock[6] > 0.09:
-                        gv.logger.debug("开盘即涨停->代码:|%s|前一天股价:|%f|开盘价|%f" % (stock[0][0:6], stock[6], stock[2]))
+                        logger.debug(
+                            "开盘即涨停->代码:|%s|前一天股价:|%f|开盘价|%f" % (stock[0][0:6], stock[6], stock[2]))
                         result.append(stock[0][0:6])
                 elif up_down.lower() == "down":
                     if (stock[6] - stock[2]) / stock[6] > 0.09 and stock[2] != 0:  # 排除停牌股票
-                        gv.logger.debug("开盘即跌停->代码:|%s|前一天股价:|%f|开盘价|%f" % (stock[0][0:6], stock[6], stock[2]))
+                        logger.debug(
+                            "开盘即跌停->代码:|%s|前一天股价:|%f|开盘价|%f" % (stock[0][0:6], stock[6], stock[2]))
                         result.append(stock[0][0:6])
                 else:
-                    gv.logger.error("参数up_down未识别！")
+                    logger.error("参数up_down未识别！")
         return result
 
     def is_working_time(self):
@@ -528,45 +536,45 @@ class StockData:
         :return: True 或 False
         """
         day_str = day_datetime.strftime("%Y%m%d")
-        if (day_datetime.weekday() == 5) or (day_datetime.weekday() == 6):  # 周六和周日肯定是休市的
+        if (day_datetime.weekday() == 5) or (day_datetime.weekday() == 6):  # 周六和周日肯定是休市的，这里的5、6分别代表周六和周日
             return True
         date_str = day_str
-        fetch = select_in_table(table_name='holiday',
-                                condition_dict={"calendarDate": date_str},
-                                result_col=['isOpen'])
-        if fetch is None:
-            gv.logger.debug("数据库中不存在假期数据表，请先初始化数据库！")
+        # fetch = select_in_table(table_name='holiday',
+        #                         condition_dict={"calendarDate": date_str},
+        #                         result_col=['isOpen'])
+        is_open = self.sql.select_in_table(table_name="Holiday", condition_dict={"calendarDate": day_datetime},
+                                           result_col=['isOpen'])
 
-        if len(fetch) == 0:  # 未查找到相关记录
+        if is_open is None:  # 未查找到相关记录
             year = day_datetime.year
             holiday_data: pd.DataFrame = self.api.query('trade_cal', start_date=f'{year}0101', end_date=f'{year}1231')
             holiday_data.rename(columns={"cal_date": "calendarDate", "is_open": "isOpen"}, inplace=True)
-            holiday_data.drop(labels="exchange", axis=1, inplace=True)
-            for date1, is_open in zip(holiday_data['calendarDate'], holiday_data['isOpen']):
-                is_open = 'Y' if is_open == 1 else 'N'
-                insert_item_to_mysql('holiday', [date1, is_open], ['calendarDate', 'isOpen'],
-                                     replace=True, filter_warning=None)
+            # 日期必须转换为datetime才能与数据库中的DATE列匹配
+            holiday_data["calendarDate"] = pd.to_datetime(holiday_data["calendarDate"])
+            holiday_data["isOpen"] = holiday_data["isOpen"].apply(lambda x: True if x == 1 else False)
 
-            if holiday_data[holiday_data['calendarDate'] == date_str]['isOpen'].values[0] == 1:
+            # to_sql()语句存储时，使用dtype参数指定dataframe到数据库的对应类型
+            holiday_data[["calendarDate", "isOpen"]].to_sql('Holiday', con=self.engine, if_exists='replace',
+                                                            index=False,
+                                                            dtype={"calendarDate": DATE, "isOpen": BOOLEAN})
+
+            if holiday_data[holiday_data['calendarDate'] == date_str]['isOpen'].item() == 'Y':
                 return False
             else:
                 return True
         else:
-            if fetch[0][0] == 'N':  # 不开市则为假日，返回True
-                return True
-            else:
-                return False
+            return is_open
 
-    def get_previous_working_day(self, last_date=date.today(), includeTime=False) -> datetime.date:
+    def get_previous_working_day(self, last_date=date.today(), include_time=False) -> datetime.date:
         """
         获得指定日期的上一个交易日，如果不传入参数，则获得最近的一个交易日，包含今天。
 
         :param last_date: 指定的日期
-        :param includeTime: 是否判断时间，如果includeTime=True，则会进一步判断今天的时间，如果时间在下午4:00之前，则不包括今天，因为当天的股票数据还没整理出来
+        :param include_time: 是否判断时间，如果includeTime=True，则会进一步判断今天的时间，如果时间在下午4:00之前，则不包括今天，因为当天的股票数据还没整理出来
         :return: 最近一个交易日日期
         """
         if last_date > date.today():
-            gv.logger.warning("因为未来的股票数据不存在，不能获得将来日期的前一个工作日！")
+            logger.warning("因为未来的股票数据不存在，不能获得将来日期的前一个工作日！")
         if self.is_holiday(last_date):
             one_day = datetime.timedelta(days=1)
             pre_day = last_date - one_day
@@ -574,7 +582,7 @@ class StockData:
                 pre_day = pre_day - one_day
             return pre_day
         else:
-            if includeTime and last_date == date.today():  # 需要判断时间，且last_date是今天
+            if include_time and last_date == date.today():  # 需要判断时间，且last_date是今天
                 dt = datetime.datetime.now()
                 hour = dt.hour
                 if hour < 16:  # 额外对时间进行判断
@@ -597,7 +605,7 @@ class StockData:
         :return: codes, lastDays 股票代码和连续跌停的天数
         """
         # 确保OpenLimit文件夹存在
-        file = os.path.join(self.dataDir, "OpenLimit")
+        file = os.path.join(self.data_folder, "OpenLimit")
         if not os.path.exists(file):
             os.mkdir(file)
         file = os.path.join(file, "recent30Down.csv")
@@ -607,7 +615,7 @@ class StockData:
         elif up_down.lower() == 'down':
             title = "跌"
         else:
-            gv.logger.debug("参数未识别，up_down只能取值'up'或'down'！")
+            logger.debug("参数未识别，up_down只能取值'up'或'down'！")
 
         # 拿到30天内每天的开盘涨/跌停股，以及对应的日期的列表
         limits, dates = self.get_open_limit_of_n_trading_days(days, up_down, sort='ascend')
@@ -718,7 +726,7 @@ class StockData:
                      '连{}后增幅2'.format(title): increase_after2, '连{}出现次数'.format(title): flags}
         df = pd.DataFrame(localData)
         df.to_csv(file, encoding="utf8", index=False)
-        gv.logger.debug("{}到{}日连续{}停股票统计：\n{}".format(dates[0], dates[-1], title, df))
+        logger.debug("{}到{}日连续{}停股票统计：\n{}".format(dates[0], dates[-1], title, df))
         return df
 
     def get_open_limit_and_lastdays(self, up_down='up', days: int = 10, last_date=date.today()):
@@ -738,13 +746,13 @@ class StockData:
             title = "Down"
             title1 = "跌停"
         else:
-            gv.logger.error("输入参数未识别，up_down只能取值'up'或'down'！")
+            logger.error("输入参数未识别，up_down只能取值'up'或'down'！")
         # 确保OpenLimit文件夹存在
-        file = os.path.join(self.dataDir, "OpenLimit")
+        file = os.path.join(self.data_folder, "OpenLimit")
         if not os.path.exists(file):  # 确保文件夹存在
             os.mkdir(file)
 
-        gv.logger.debug("获取{}的{}股代码及持续天数...".format(last_date, title1))
+        logger.debug("获取{}的{}股代码及持续天数...".format(last_date, title1))
         config.holdLoggingLevel(logging.WARN)
         limits, dates = self.get_open_limit_of_n_trading_days(days, up_down, 'descend', last_date=last_date)
         config.holdLoggingLevel('end')
@@ -768,7 +776,7 @@ class StockData:
             data = {'股票代码': codes, '持续天数': lastDays}
             df = pd.DataFrame(data)
             df.to_csv(file, encoding=self.encode, index=False)
-        gv.logger.debug("get_open_limit_and_lastdays()获得{}的{}股和持续天数：\n{}".format(last_date, title1, df))
+        logger.debug("get_open_limit_and_lastdays()获得{}的{}股和持续天数：\n{}".format(last_date, title1, df))
         return df
 
     def get_open_limit_of_n_trading_days(self, days=30, up_down='up',
@@ -787,18 +795,18 @@ class StockData:
         elif up_down.lower() == 'down':
             tmp = '跌停'
         else:
-            gv.logger.error("参数未识别，up_down只能取值'up'或'down'！")
+            logger.error("参数未识别，up_down只能取值'up'或'down'！")
         config.loggingTitle("获取最近{}个交易日的{}信息".format(days, tmp), 'start')
         date_times = self.get_last_n_working_day(days, sort, last_date=last_date)
         open_limit_list = []
 
         for day_datetime in date_times:
-            gv.logger.debug("获取{}的开盘{}股...".format(day_datetime, tmp))
+            logger.debug("获取{}的开盘{}股...".format(day_datetime, tmp))
             config.holdLoggingLevel(logging.WARN)  # 临时将日志级别调高到警告，以取消局部的DEBUG日志输出
             limit = self.get_open_limit(up_down, day_datetime)
             open_limit_list.append(limit)
             config.holdLoggingLevel('end')  # 恢复日志输出级别
-            gv.logger.debug("{}的开盘{}股有：{}".format(day_datetime, tmp, limit))
+            logger.debug("{}的开盘{}股有：{}".format(day_datetime, tmp, limit))
 
         config.loggingTitle("获取最近{}个交易日的{}信息".format(days, tmp), 'end')
         return open_limit_list, date_times
@@ -813,7 +821,7 @@ class StockData:
         """
         # day = day_datetime.strftime("%Y-%m-%d")
         if day_num < -1:
-            gv.logger.error("day_num不能取-1以外的负值（{}）".format(day_num))
+            logger.error("day_num不能取-1以外的负值（{}）".format(day_num))
             return None
         if day_num == 1 or day_num == -1:
             one_day = datetime.timedelta(days=1)
@@ -850,3 +858,15 @@ class StockData:
         low = float(data['low'])
         now_price = float(data['price'])
         return name, now_price, open_price, high, low
+
+    def init_storage(self):
+        """
+        初始化存储的数据库操作对象
+        """
+        if self.storage == "Sqlite数据库":
+            if self.engine is None:
+                self.engine = create_engine(f'sqlite:///{self.project.db_name}', echo=True, encoding=self.encoding)
+                self.sql = SqlOperator(self.engine)
+                self.sql.create_all_base_table()
+            else:
+                pass
