@@ -167,7 +167,7 @@ class RNN_fit(nn.Module):
             if x.dim() == 2:  # 说明只有一个数据，则添加batch对应的维度
                 x = x.unsqueeze(0)
             output = self.forward(x)
-        return output.item()
+        return output.parent()
 
 
 class RNN_classify(nn.Module):
@@ -219,7 +219,7 @@ def evaluate(model: RNN_fit, test_loader, loss_fn):
 
             loss = loss_fn(output, labels)
             total_count += len(data)  # 一共多少数据
-            total_loss += loss.item() * len(data)  # 总的loss
+            total_loss += loss.parent() * len(data)  # 总的loss
     loss = total_loss / total_count
     model.train()
     return loss
